@@ -2,7 +2,8 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2024 Osimis S.A., Belgium
+ * Copyright (C) 2017-2023 Osimis S.A., Belgium
+ * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
  * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
@@ -389,6 +390,13 @@ OrthancPluginErrorCode TranscoderCallback(
           throw Orthanc::OrthancException(Orthanc::ErrorCode_NotImplemented, "Cannot transcode 1bpp DICOM images");
         }
 
+        gdcm::DataSet ds = reader.GetFile().GetDataSet();
+        const gdcm::Tag sfgs(0x5200,0x9229); // SharedFunctionalGroupsSequence
+        if (ds.FindDataElement(sfgs) && ds.GetDataElement(sfgs).IsEmpty())
+        {
+          throw Orthanc::OrthancException(Orthanc::ErrorCode_NotImplemented, "Cannot transcode DICOM images with empty 5200,9229 sequence");
+        }
+ 
 #if !GDCM_VERSION_IS_ABOVE(3, 0, 9)
         if (reader.GetImage().GetPixelFormat().GetBitsStored() == 16u &&
             syntax == gdcm::TransferSyntax::JPEGExtendedProcess2_4)
@@ -539,18 +547,41 @@ extern "C"
 
         enabled = config.GetBooleanValue(KEY_ENABLE_GDCM, true);
 
-        if (enabled &&
-            config.LookupSetOfStrings(enabledTransferSyntaxes_, KEY_RESTRICT_TRANSFER_SYNTAXES, false))
+        if (enabled)
         {
-          restrictTransferSyntaxes_ = true;
-        
-          for (std::set<std::string>::const_iterator it = enabledTransferSyntaxes_.begin();
-               it != enabledTransferSyntaxes_.end(); ++it)
+          if (config.LookupSetOfStrings(enabledTransferSyntaxes_, KEY_RESTRICT_TRANSFER_SYNTAXES, false))
           {
-            LOG(WARNING) << "Orthanc will use GDCM to decode transfer syntax: " << *it;
+            if (enabledTransferSyntaxes_.size() == 0)
+            {
+              restrictTransferSyntaxes_ = false;
+              LOG(WARNING) << KEY_GDCM << "." << KEY_RESTRICT_TRANSFER_SYNTAXES << " configuration is set but empty, Orthanc will use GDCM to transcode ALL transfer syntaxes.";
+            }
+            else
+            {
+              LOG(WARNING) << KEY_GDCM << "." << KEY_RESTRICT_TRANSFER_SYNTAXES << " configuration is set and not empty, Orthanc will use GDCM to transcode SOME transfer syntaxes:";
+            }
+          }
+          else
+          {
+            LOG(WARNING) << KEY_GDCM << "." << KEY_RESTRICT_TRANSFER_SYNTAXES << " configuration is not set, using default configuration. Orthanc will use GDCM to transcode only J2K transfer syntaxes:";
+            enabledTransferSyntaxes_.insert("1.2.840.10008.1.2.4.90"); // JPEG 2000 Image Compression (Lossless Only)
+            enabledTransferSyntaxes_.insert("1.2.840.10008.1.2.4.91"); // JPEG 2000 Image Compression
+            enabledTransferSyntaxes_.insert("1.2.840.10008.1.2.4.92"); // JPEG 2000 Part 2 Multicomponent Image Compression (Lossless Only)
+            enabledTransferSyntaxes_.insert("1.2.840.10008.1.2.4.93"); // JPEG 2000 Part 2 Multicomponent Image Compression
+          }
+
+          if (enabledTransferSyntaxes_.size() > 0)
+          {
+            restrictTransferSyntaxes_ = true;
+            for (std::set<std::string>::const_iterator it = enabledTransferSyntaxes_.begin();
+                it != enabledTransferSyntaxes_.end(); ++it)
+            {
+              LOG(WARNING) << "Orthanc will use GDCM to decode transfer syntax: " << *it;
+            }
           }
         }
 
+
         unsigned int throttling;
         if (enabled &&
             config.LookupUnsignedIntegerValue(throttling, KEY_THROTTLING))
